Struct parquet::schema::types::BasicTypeInfo[][src]

pub struct BasicTypeInfo { /* fields omitted */ }

Basic type info. This contains information such as the name of the type, the repetition level, the logical type and the kind of the type (group, primitive).

Methods

impl BasicTypeInfo
[src]

Returns field name.

Returns true if type has repetition field set, false otherwise. This is mostly applied to group type, because primitive type always has repetition set.

Returns Repetition value for the type.

Returns LogicalType value for the type.

Returns true if id is set, false otherwise.

Returns id value for the type.