Struct parquet::schema::types::GroupTypeBuilder [−][src]
pub struct GroupTypeBuilder<'a> { /* fields omitted */ }A builder for group types. All attributes are optional except the name.
Note that if not specified explicitly, None is used as the repetition of the group,
which means it is a root (message) type.
Methods
impl<'a> GroupTypeBuilder<'a>[src]
impl<'a> GroupTypeBuilder<'a>pub fn new(name: &'a str) -> Self[src]
pub fn new(name: &'a str) -> SelfCreates new group type builder with provided field name.
pub fn with_repetition(self, repetition: Repetition) -> Self[src]
pub fn with_repetition(self, repetition: Repetition) -> SelfSets Repetition for this field and returns itself.
pub fn with_logical_type(self, logical_type: LogicalType) -> Self[src]
pub fn with_logical_type(self, logical_type: LogicalType) -> SelfSets LogicalType for this field and returns itself.
pub fn with_fields(self, fields: &mut Vec<TypePtr>) -> Self[src]
pub fn with_fields(self, fields: &mut Vec<TypePtr>) -> SelfSets a list of fields that should be child nodes of this field. Returns updated self.
pub fn with_id(self, id: i32) -> Self[src]
pub fn with_id(self, id: i32) -> SelfSets optional field id and returns itself.
pub fn build(self) -> Result<Type>[src]
pub fn build(self) -> Result<Type>Creates a new GroupType instance from the gathered attributes.