Struct parquet::schema::types::BasicTypeInfo [−][src]
pub struct BasicTypeInfo { /* fields omitted */ }Basic type info. This contains information such as the name of the type, the repetition level, the logical type and the kind of the type (group, primitive).
Methods
impl BasicTypeInfo[src]
impl BasicTypeInfopub fn name(&self) -> &str[src]
pub fn name(&self) -> &strReturns field name.
pub fn has_repetition(&self) -> bool[src]
pub fn has_repetition(&self) -> boolReturns true if type has repetition field set, false otherwise.
This is mostly applied to group type, because primitive type always has
repetition set.
pub fn repetition(&self) -> Repetition[src]
pub fn repetition(&self) -> RepetitionReturns Repetition value for the type.
pub fn logical_type(&self) -> LogicalType[src]
pub fn logical_type(&self) -> LogicalTypeReturns LogicalType value for the type.
pub fn has_id(&self) -> bool[src]
pub fn has_id(&self) -> boolReturns true if id is set, false otherwise.
pub fn id(&self) -> i32[src]
pub fn id(&self) -> i32Returns id value for the type.